@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -13,6 +13,7 @@ import sys
 import os
 import parse_datetime
 import glob
+import locale
 
 class CommandError( Exception ):
     def __init__( self, reason ):
@@ -31,14 +32,40 @@ def main( args ):
     if args[1:2] == ['--pause']:
         del args[1]
         pause = True
+
+    # if the locale is not setup SVN can report errors handling non ascii file names
+    initLocale()
+
     svn_cmd = SvnCommand( progname )
     rc = svn_cmd.dispatch( args[1:] )
     if pause:
         sys.stdin.readline()
     return rc
 
+def initLocale():
+    # init the locale
+    if sys.platform == 'win32':
+        locale.setlocale( locale.LC_ALL, '' )
+
+    else:
+        language_code, encoding = locale.getdefaultlocale()
+        if language_code is None:
+            language_code = 'en_GB'
+
+        if encoding is None:
+            encoding = 'UTF-8'
+        if encoding.lower() == 'utf':
+            encoding = 'UTF-8'
+
+        try:
+            # setlocale fails when params it does not understand are passed
+            locale.setlocale( locale.LC_ALL, '%s.%s' % (language_code, encoding) )
+        except locale.Error:
+            # force a locale that will work
+            locale.setlocale( locale.LC_ALL, 'en_GB.UTF-8' )
+
 def fmtDateTime( t ):
-    return time.strftime( '%d-%b-%Y %X', time.localtime( t ) )
+    return time.strftime( '%d-%b-%Y %H:%M:%S', time.localtime( t ) )
 
 wc_status_kind_map = {
 pysvn.wc_status_kind.added: 'A',
@@ -112,7 +139,6 @@ class SvnCommand:
         self.client.callback_ssl_server_prompt = self.callback_ssl_server_prompt
         self.client.callback_ssl_server_trust_prompt = self.callback_ssl_server_trust_prompt
 
-
     def callback_ssl_client_cert_password_prompt( self ):
         print 'callback_ssl_client_cert_password_prompt'
 
@@ -144,7 +170,7 @@ class SvnCommand:
             self.revision_update_complete = arg_dict['revision']
         elif arg_dict['path'] != '' and wc_notify_action_map[ arg_dict['action'] ] is not None:
             msg = '%s %s' % (wc_notify_action_map[ arg_dict['action'] ], arg_dict['path'])
-            if self.pysvn_testing:
+            if self.pysvn_testing != '99.99.99':
                 self.notify_message_list.append( msg )
             else:
                 print msg
@@ -186,7 +212,7 @@ class SvnCommand:
 
             self.initClient( args.getOptionalValue( '--config-dir', '' ) )
             self.client.set_auth_cache( args.getBooleanOption( '--no-auth-cache', False ) )
-            self.pysvn_testing = args.getBooleanOption( '--pysvn-testing', True )
+            self.pysvn_testing = args.getOptionalValue( '--pysvn-testing', '99.99.99' )
             self.debug_enabled = args.getBooleanOption( '--debug', True )
 
             getattr( self, cmd_name, self.cmd_help )( args )
@@ -332,10 +358,6 @@ class SvnCommand:
 
         tmpdir = os.path.join( tmpdir, 'svn_tmp' )
         self.debug( 'cmd_diff %r, %r, %r, %r, %r' % (tmpdir, positional_args[0], recurse, revision1, revision2) )
-        diff_text = self.client.diff( tmpdir, positional_args[0] )
-        print diff_text
-        diff_text = self.client.diff( tmpdir, positional_args[0], recurse=recurse )
-        print diff_text
         diff_text = self.client.diff( tmpdir, positional_args[0], recurse=recurse, revision1=revision1, revision2=revision2 )
         print diff_text
 
@@ -366,7 +388,7 @@ class SvnCommand:
             print 'Name:',entry.name
         if entry.url:
             print 'Url:',entry.url
-        if entry.repos:
+        if entry.repos and self.pysvn_testing >= '01.03.00':
             print 'Repository:',entry.repos
         if entry.uuid:
             print 'Repository UUID:',entry.uuid
@@ -409,12 +431,20 @@ class SvnCommand:
 
     def cmd_info2( self, args ):
         recurse = args.getBooleanOption( '--recursive', True )
-        revision = args.getOptionalRevision( '--revision', 'unspecified' )
+        revision_url = args.getOptionalRevision( '--revision', 'head' )
+        revision_path = args.getOptionalRevision( '--revision', 'unspecified' )
+
         positional_args = args.getPositionalArgs( 0, 1 )
         if len(positional_args) == 0:
             positional_args.append( '.' )
+
         path = positional_args[0]
 
+        if self.client.is_url( path ):
+            revision = revision_url
+        else:
+            revision = revision_path
+
         all_entries = self.client.info2( path, revision=revision,  recurse=recurse )
 
         for path, info in all_entries:
@@ -425,7 +455,7 @@ class SvnCommand:
                 print 'Url:',info['URL']
             if info['rev']:
                 print 'Revision:',info['rev'].number
-            if info['repos_root_URL']:
+            if info['repos_root_URL'] and self.pysvn_testing >= '01.03.00':
                 print 'Repository root URL:',info['repos_root_URL']
             if info['repos_UUID']:
                 print 'Repository UUID:',info['repos_UUID']
@@ -736,7 +766,6 @@ class SvnCommand:
             if file.text_status == pysvn.wc_status_kind.ignored and ignore:
                 continue
 
-
             state = '%s%s%s%s%s' % (wc_status_kind_map[ file.text_status ],
                     wc_status_kind_map[ file.prop_status ],
                     ' L'[ file.is_locked ],
@@ -755,6 +784,9 @@ class SvnCommand:
                 if file.entry.lock_token is not None:
                     lock_state = 'K'
 
+            if hasattr( file, 'repos_lock' ) and file.repos_lock is not None:
+                lock_state = 'O'
+
             if file.entry is not None and detailed:
                 print '%s%s %s %6d %6d %-14s %s' % (state, lock_state,
                     odd_status,
@@ -810,8 +842,10 @@ class SvnCommand:
         positional_args = args.getPositionalArgs( 0 )
         if len(positional_args) == 0:
             positional_args.append( '.' )
-        rev = self.client.update( positional_args[0], recurse=recurse )
+        rev_list = self.client.update( positional_args[0], recurse=recurse )
         self.printNotifyMessages()
+        if type(rev_list) == type([]) and len(rev_list) != 1:
+            print 'rev_list = %r' % [rev.number for rev in rev_list]
 
         if self.revision_update_complete is not None:
             print 'Updated to revision',self.revision_update_complete.number
@@ -872,7 +906,7 @@ long_opt_info = {
     '--show-updates': 0,        # display update information
     '--verbose': 0,             # print extra information
     '--extensions': 1,          # pass ARG as bundled options to GNU diff
-    '--pysvn-testing': 0,       # modify behaviour to assist testing pysvn
+    '--pysvn-testing': 1,       # modify behaviour to assist testing pysvn
     '--debug': 0,               # do debug stuff
 }
 
