@@ -52,26 +52,29 @@ public:
 
     void checkForError( Py::ExtensionExceptionType &exception_for_error );
 
-public:    // data
+public:     // data
 
     //
     // Python class that has implements the callback methods
     //
-    Py::Object m_pyfn_GetLogin;
-    Py::Object m_pyfn_Notify;
+    Py::Object  m_pyfn_GetLogin;
+    Py::Object  m_pyfn_Notify;
 #ifdef PYSVN_HAS_CONTEXT_PROGRESS
-    Py::Object m_pyfn_Progress;
+    Py::Object  m_pyfn_Progress;
 #endif
-    Py::Object m_pyfn_Cancel;
-    Py::Object m_pyfn_GetLogMessage;
-    Py::Object m_pyfn_SslServerPrompt;
-    Py::Object m_pyfn_SslServerTrustPrompt;
-    Py::Object m_pyfn_SslClientCertPrompt;
-    Py::Object m_pyfn_SslClientCertPwPrompt;
+    Py::Object  m_pyfn_Cancel;
+    Py::Object  m_pyfn_GetLogMessage;
+    Py::Object  m_pyfn_SslServerPrompt;
+    Py::Object  m_pyfn_SslServerTrustPrompt;
+    Py::Object  m_pyfn_SslClientCertPrompt;
+    Py::Object  m_pyfn_SslClientCertPwPrompt;
+
+    std::string m_default_username;
+    std::string m_default_password;
 
     void setLogMessage( const std::string &message );
 
-private:// methods
+private:    // methods
 
     //
     // this method will be called to retrieve
@@ -166,11 +169,14 @@ private:// methods
 
 private:// vaiables
 
-    PythonAllowThreads    *m_permission;
-    std::string        m_error_message;
-    std::string        m_log_message;
+    PythonAllowThreads  *m_permission;
+    std::string         m_error_message;
+    std::string         m_log_message;
+
 };
 
+class FunctionArguments;
+
 class pysvn_client : public Py::PythonExtension<pysvn_client>
 {
 public:
@@ -232,6 +238,14 @@ public:
     Py::Object set_auth_cache( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object get_auto_props( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object set_auto_props( const Py::Tuple& args, const Py::Dict &kws );
+    Py::Object get_interactive( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object set_interactive( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object get_default_username( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object set_default_username( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object get_default_password( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object set_default_password( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object get_store_passwords( const Py::Tuple &a_args, const Py::Dict &a_kws );
+    Py::Object set_store_passwords( const Py::Tuple &a_args, const Py::Dict &a_kws );
 
     // check that we are not in use on another thread
     void checkThreadPermission();
@@ -239,6 +253,12 @@ private:
     // helper function that wraps up the logic to throw a client error exception
     void throw_client_error( SvnException & );
 private:
+    Py::Object helper_boolean_auth_set( FunctionArguments &a_args, const char *a_arg_name, const char *a_param_name );
+    Py::Object helper_boolean_auth_get( FunctionArguments &a_args, const char *a_param_name );
+    Py::Object helper_string_auth_set( FunctionArguments &a_args,
+                                        const char *a_arg_name, const char *a_param_name, std::string &ctx_str );
+    Py::Object helper_string_auth_get( FunctionArguments &a_args, const char *a_param_name );
+
     pysvn_module    &m_module;
     pysvn_context   m_context;
     int             m_exception_style;
@@ -295,7 +315,7 @@ public:
 
     virtual Py::Object getattr( const char *name );
     virtual int setattr( const char *name, const Py::Object &value );
-    virtual Py::Object pysvn_revision::repr();
+    virtual Py::Object repr();
 
     const svn_opt_revision_t &getSvnRevision() const;
 
