@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -165,7 +165,7 @@ Py::Object FunctionArguments::getArg( const char *arg_name )
     if( !hasArg( arg_name ) )
     {
         std::string msg = m_function_name;
-        msg += "() internal error - getArg called twice of with bad arg_name: ";
+        msg += "() internal error - getArg called twice or for option arg that is missing with bad arg_name: ";
         msg += arg_name;
         throw Py::AttributeError( msg );
     }
@@ -194,6 +194,23 @@ bool FunctionArguments::getBoolean( const char *name, bool default_value )
     }
 }
 
+int FunctionArguments::getInteger( const char *name )
+{
+    Py::Int int_val( getArg( name ) );
+    return int_val;
+}
+
+int FunctionArguments::getInteger( const char *name, int default_value )
+{
+    if( hasArg( name ) )
+    {
+        return getInteger( name );
+    }
+    else
+    {
+        return default_value;
+    }
+}
 std::string FunctionArguments::getUtf8String( const char *name )
 {
     Py::String any( getArg( name ) );
@@ -269,3 +286,20 @@ svn_opt_revision_t FunctionArguments::getRevision
         return revision;
     }
 }
+
+svn_opt_revision_t FunctionArguments::getRevision
+    (
+    const char *name,
+    svn_opt_revision_t default_value
+    )
+{
+
+    if( hasArg( name ) )
+    {
+        return getRevision( name );
+    }
+    else
+    {
+        return default_value;
+    }
+}
