@@ -1,6 +1,6 @@
 //
 // ====================================================================
-// Copyright (c) 2003-2005 Barry A Scott.  All rights reserved.
+// Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
 //
 // This software is licensed as described in the file LICENSE.txt,
 // which you should have received as part of this distribution.
@@ -141,8 +141,21 @@ Py::Object pysvn_status::getattr( const char *_name )
     {
         return toEnumValue( m_svn_status->repos_text_status );
     }
-    else
-        return getattr_methods( _name );
+#ifdef PYSVN_HAS_CLIENT_LOCK
+    else if( name == "repos_lock" )
+    {
+        if( m_svn_status->repos_lock == NULL )
+        {
+            return Py::None();
+        }
+        else
+        {
+            return toObject( m_svn_status->repos_lock );
+        }
+    }
+#endif
+
+    return getattr_methods( _name );
 }
 
 static const char class_doc[] =
